Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/moses-smt/mosesdecoder.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBarry Haddow <barry.haddow@gmail.com>2014-08-08 00:20:10 +0400
committerBarry Haddow <barry.haddow@gmail.com>2014-08-08 00:20:10 +0400
commitb5a1f02606f83209e0a1fe771f329cb9eedcef57 (patch)
tree4e71efa21deb703d149d8be2edf844be01b70f2f /moses/ChartCell.cpp
parentfbe73dd06f89e0b17d9f3ec9e82d5c8f2add7fbd (diff)
Implement hypergraph output for chart moses
Diffstat (limited to 'moses/ChartCell.cpp')
-rw-r--r--moses/ChartCell.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/moses/ChartCell.cpp b/moses/ChartCell.cpp
index 125efd204..269d6cdfd 100644
--- a/moses/ChartCell.cpp
+++ b/moses/ChartCell.cpp
@@ -22,6 +22,7 @@
#include <algorithm>
#include "ChartCell.h"
#include "ChartCellCollection.h"
+#include "HypergraphOutput.h"
#include "RuleCubeQueue.h"
#include "RuleCube.h"
#include "WordsRange.h"
@@ -195,13 +196,13 @@ const HypoList *ChartCell::GetAllSortedHypotheses() const
return ret;
}
-//! call GetSearchGraph() for each hypo collection
-void ChartCell::GetSearchGraph(long translationId, std::ostream &outputSearchGraphStream, const std::map<unsigned, bool> &reachable) const
+//! call WriteSearchGraph() for each hypo collection
+void ChartCell::WriteSearchGraph(const ChartSearchGraphWriter& writer, const std::map<unsigned, bool> &reachable) const
{
MapType::const_iterator iterOutside;
for (iterOutside = m_hypoColl.begin(); iterOutside != m_hypoColl.end(); ++iterOutside) {
const ChartHypothesisCollection &coll = iterOutside->second;
- coll.GetSearchGraph(translationId, outputSearchGraphStream, reachable);
+ coll.WriteSearchGraph(writer, reachable);
}
}